# eric7.Plugins.VcsPlugins.vcsPySvn.SvnUtilities

Module implementing some common utility functions for the pysvn package.

### Global Attributes

None

### Classes

None

### Functions

amendConfig | Module function to amend the config file.
createDefaultConfig | Module function to create a default config file suitable for eric.
dateFromTime_t | Module function to return the date.
formatTime | Module function to return a formatted time string.
getConfigPath | Module function to get the filename of the config file.
getServersPath | Module function to get the filename of the servers file.

## amendConfig

amendConfig()

Module function to amend the config file.

Up

## createDefaultConfig

createDefaultConfig()

Module function to create a default config file suitable for eric.

Up

## dateFromTime_t

dateFromTime_t(seconds)

Module function to return the date.

seconds (float or int)
  time in seconds since epoch to be formatted

Return:
  date

Return Type:
  QDate

Up

## formatTime

formatTime(seconds)

Module function to return a formatted time string.

seconds (float or int)
  time in seconds since epoch to be formatted

Return:
  formatted time string

Return Type:
  str

Up

## getConfigPath

getConfigPath()

Module function to get the filename of the config file.

Return:
  filename of the config file

Return Type:
  str

Up

## getServersPath

getServersPath()

Module function to get the filename of the servers file.

Return:
  filename of the servers file

Return Type:
  str

Up